@@ -8,7 +8,7 @@ class Model:
 
         movie_rating_predictions = []
         for movie in user_movie_list:
-            predicted_rating = self.model.predictions(user_id, movie)
+            predicted_rating = self.model.predict(user_id, movie)
             movie_rating_predictions.append((movie, predicted_rating))
 
         movie_ranking = sorted(movie_rating_predictions, key = lambda movie_rating_tuple: movie_rating_tuple[1], reverse=True)
