@@ -3,20 +3,23 @@ from sqlalchemy import create_engine, Column, Text, SmallInteger, Integer, TIMES
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
-class RDSDatabase:
+class Database:
     def __init__(self, user, password, host, port, database, **kwargs):
         self.engine = create_engine('postgresql://{}:{}@{}:{}/{}'.format(
                 user, password, host, port, database
             ), **kwargs)
-        Base = declarative_base(self.engine)
-        self.Movie = self._create_movie_class(Base)
-        self.User = self._create_user_class(Base)
-        self.Rating = self._create_rating_class(Base)
-
+        self.Base = declarative_base(self.engine)
+    
     def load_session(self):
         # TODO: should we checkout scoped sessions
         Session = sessionmaker(bind=self.engine)
         return Session()
+class RDSDatabase(Database):
+    def __init__(self, user, password, host, port, database, **kwargs):
+        super().__init__(user, password, host, port, database, **kwargs)
+        self.Movie = self._create_movie_class(self.Base)
+        self.User = self._create_user_class(self.Base)
+        self.Rating = self._create_rating_class(self.Base)
  
     def _create_movie_class(self, base):
         class Movie(base):
@@ -39,15 +42,12 @@ class RDSDatabase:
             rating = Column(SmallInteger)
         return Rating
 
-class TSDatabase():
+class TSDatabase(Database):
     def __init__(self, user, password, host, port, database, **kwargs):
-        self.engine = create_engine('postgresql://{}:{}@{}:{}/{}'.format(
-                user, password, host, port, database
-            ), **kwargs)
-        Base = declarative_base(self.engine)
-        self.Recommendation = self._create_recommendation_class(Base)
-        self.View = self._create_view_class(Base)
-        self.Rating = self._create_rating_class(Base)
+        super().__init__(user, password, host, port, database, **kwargs)
+        self.Recommendation = self._create_recommendation_class(self.Base)
+        self.View = self._create_view_class(self.Base)
+        self.Rating = self._create_rating_class(self.Base)
 
     def _create_recommendation_class(self, base):
         class Recommendation(base):
